translate.lang.ne.ne

Package translate :: Package lang :: Module ne :: Class ne |
[hide private]
[frames] | no frames]

# Class ne

source code

This class represents Nepali.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `common.Common`: `alter_length`, `capsstart`, `character_iter`, `characters`, `length_difference`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| sentenceend = ``u'``।!?…``'`` These marks can indicate a sentence end.
| sentencere = `re.compile(r'`(?sx)`.`*?`\s`?``[`\u0964!\?\u2026`]`\s`+``(?=``[``^``...``
| puncdict = ``{``u'``.``'``:` `u'``।``'``,` `u'``?``'``:` `u'``?``'``}`` A dictionary of punctuation transformation rules that can be used by punctranslate().
| ignoretests = ``[``'``startcaps``'``,` `'``simplecaps``'``,` `'``accelerators``'``]`` List of pofilter tests for this language that must be ignored.
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `punctuation`, `quotes`, `rtlpunc`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### sentencere Value:
      re.compile(r'(?sx).*?\s?[\u0964!\?\u2026]\s+(?=[^a-z\d])')